@@ -18,15 +18,15 @@ def send_get(url, params=None, headers=HEADER):
 
 
 def send_post(url, data={}, headers=HEADER):
-    response = requests.post(url=url, data=data, headers=headers)
+    response = requests.post(url=url, json=data, headers=headers)
     return ret(response)
 
 
 def send_put(url, data={}, headers=HEADER):
-    response = requests.put(url=url, data=data, headers=headers)
+    response = requests.put(url=url, json=data, headers=headers)
     return ret(response)
 
 
 def send_delete(url, data={}, headers=HEADER):
-    response = requests.delete(url=url, data=data, headers=headers)
+    response = requests.delete(url=url, json=data, headers=headers)
     return ret(response)
